#!/usr/bin/env perl

# export PERL5LIB=@prefix@/lib

use strict;
use warnings;
use Pod::Usage;
use Smash::Batch;
use Smash::Global qw(:all);
use Smash::CommandLineParser qw(:all);

##############
# Set up command line parsing
##############

my @allowed  = qw(batch=s help); # arguments I expect
my @required = qw(batch);                       # arguments I require

##############
# Parse command line options
##############

my $status;
my $missing;
my %options;

($status, %options) = parse_options(\@allowed);
if ($options{help}) {
	pod2usage(-exitstatus => 0, -verbose => 2);
}
if ($status != 1) {
	pod2usage(-message => "", -exitstatus => 2, -verbose => 1);
}
#print_options(%options);
($status, $missing) = check_required_options(\@required, %options);
if ($status != 1) {
	pod2usage(-message => "$SMASH_SCRIPT_NAME: Missing argument --$missing\n", -exitstatus => 2, -verbose => 1);
}

##############
# Run
##############

my $batch = "";
my $batch_file = $options{batch};
open(BATCH, "<$batch_file") || die "Cannot open $batch_file: $!";
while (<BATCH>) {
	$batch .= $_;
}
close(BATCH);

my $test = new Smash::Batch();
$test->process_batch($batch);

exit(0);

__END__

=head1 Name

runBatch.pl - Run batch commands for Smash.

=head1 Synopsis

	runBatch.pl [options]

=head1 Options

=over 4

=item B<C<--batch>>

File containing batch commands

=item B<C<--help>>

Prints this manual.

=back

=head1 Description

B<runBatch.pl> is a script that automates running batch jobs for Smash.

=head1 Author

Mani Arumugam (arumugam@embl.de, http://www.embl.de)

=head1 Copyright

Copyright (C) 2008-2009. Mani Arumugam and EMBL. All rights reserved.

=cut
